# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...commons.types.base_paginated_request import BasePaginatedRequest
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from .customer_field import CustomerField
from .customer_filter import CustomerFilter


class CustomersSearchRequest(BasePaginatedRequest):
    sort: typing.Optional[CustomerField] = pydantic.Field(default=None)
    """
    The field to sort by, defaults to created timestamp
    """

    filter: typing.Optional[CustomerFilter] = pydantic.Field(default=None)
    """
    The filter to apply to the customers.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
