# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from .event_base_no_id import EventBaseNoId
from .system_event_name import SystemEventName


class NovelSystemEventNoId(EventBaseNoId):
    event_name: typing_extensions.Annotated[SystemEventName, FieldMetadata(alias="eventName")] = pydantic.Field()
    """
    The name of the event
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
