# This file was auto-generated by Fern from our API Definition.

import typing

ActionParameterType = typing.Union[
    typing.Literal[
        "STRING",
        "MULTILINE",
        "BOOLEAN",
        "NUMBER",
        "DATETIME",
        "DATE",
        "TIME",
        "EMAIL",
        "PHONE",
        "SCHEMA",
        "FILE",
        "OAUTH",
    ],
    typing.Any,
]
