# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .audio_format import AudioFormat


class Config(UniversalBaseModel):
    """
    Initialize conversation with configuration parameters
    """

    type: typing.Literal["config"] = "config"
    input_format: typing_extensions.Annotated[AudioFormat, FieldMetadata(alias="inputFormat")] = pydantic.Field()
    """
    The user text to send into the conversation.
    """

    output_format: typing_extensions.Annotated[AudioFormat, FieldMetadata(alias="outputFormat")] = pydantic.Field()
    """
    The user text to send into the conversation.
    """

    conversation_id: typing_extensions.Annotated[str, FieldMetadata(alias="conversationId")] = pydantic.Field()
    """
    The conversation ID which was created prior to starting this conversation.
    """

    app_id: typing_extensions.Annotated[str, FieldMetadata(alias="appId")] = pydantic.Field()
    """
    The app ID this conversation ID is associated with.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
