# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...commons.types.entity_id import EntityId
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from .customer_base import CustomerBase


class CustomerResponse(CustomerBase):
    """
    Examples
    --------
    from mavenagi.commons import EntityId
    from mavenagi.customers import CustomerResponse

    CustomerResponse(
        customer_id=EntityId(
            reference_id="acme",
            app_id="customer-app",
            organization_id="acme",
            agent_id="support",
            type="CUSTOMER",
        ),
        name="Acme Corporation",
        status="ACTIVE",
        description="Acme is a company that makes widgets",
        metadata={
            "industry": "widget manufacturing",
            "initial-note": "Acme is a great company",
        },
        assignees=[],
        members=[],
    )
    """

    customer_id: typing_extensions.Annotated[EntityId, FieldMetadata(alias="customerId")] = pydantic.Field()
    """
    ID that uniquely identifies this customer
    """

    assignees: typing.Set[str] = pydantic.Field()
    """
    Set of agent user IDs assigned to this customer
    """

    members: typing.Set[str] = pydantic.Field()
    """
    Set of agent user IDs who are members of this customer
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
