# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...commons.types.page import Page
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from .customer_response import CustomerResponse


class CustomersSearchResponse(Page):
    customers: typing.List[CustomerResponse]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
